import { Dict, Plugin, Message } from 'zhin';
declare module 'zhin' {
    namespace Message {
        interface Sender {
            github_accessToken?: string;
            github_refreshToken?: string;
        }
    }
}
export type ReplyPayloads = {
    [K in keyof ReplyHandler]?: ReplyHandler[K] extends (...args: infer P) => any ? P : never;
};
type Method = 'get' | 'GET' | 'delete' | 'DELETE' | 'head' | 'HEAD' | 'options' | 'OPTIONS' | 'post' | 'POST' | 'put' | 'PUT' | 'patch' | 'PATCH' | 'purge' | 'PURGE' | 'link' | 'LINK' | 'unlink' | 'UNLINK';
export declare class GitHub {
    plugin: Plugin;
    config: Config;
    history: Dict<ReplyPayloads>;
    private http;
    constructor(plugin: Plugin, config: Config);
    init(): Promise<void>;
    getTokens(params: any): Promise<any>;
    private _request;
    authorize(message: Message, raw_message: string): Promise<void>;
    request(method: Method, url: string, message: Message, body?: any, headers?: Dict): Promise<any>;
}
export interface Config {
    path?: string;
    appId?: string;
    appSecret?: string;
    messagePrefix?: string;
    redirect?: string;
    promptTimeout?: number;
    replyTimeout?: number;
    requestTimeout?: number;
}
export declare class ReplyHandler {
    github: GitHub;
    ctxMessage: Message;
    content?: string | undefined;
    constructor(github: GitHub, ctxMessage: Message, content?: string | undefined);
    request(method: Method, url: string, message: string, body?: any, headers?: Dict): Promise<string | undefined>;
    link(url: string): string;
    react(url: string): Promise<string | undefined>;
    transform(source: string): Promise<any>;
    reply(url: string, params?: Dict): Promise<string | undefined>;
    base(url: string): Promise<string | undefined>;
    merge(url: string, method?: 'merge' | 'squash' | 'rebase'): Promise<string | undefined>;
    rebase(url: string): Promise<string | undefined>;
    squash(url: string): Promise<string | undefined>;
    close(url: string, commentUrl: string): Promise<void>;
}
export {};
